@@ -204,6 +204,11 @@ class SGrid(object):
         return all_padding
 
     def save_as_netcdf(self, filepath):
+        """
+        save the grid as a netcdf file
+
+        :param filepath: path to the file to be created and saved to
+        """
         with Dataset(filepath, 'w') as nclocal:
             grid_vars = self._save_common_components(nclocal)
             # Add attributes to the grid_topology variable.
@@ -664,8 +669,6 @@ class SGrid(object):
             lin_nodes = np.ascontiguousarray(np.stack((lon, lat), axis=-1).reshape(-1, 2).astype(np.float64))
 
         self._cell_trees[grid] = (CellTree(lin_nodes, lin_faces), lin_nodes, lin_faces)
-        print(lin_nodes)
-        print(lin_faces)
 
 
     def nearest_var_to_points(self,
